==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Effect/ladspa/translations/ladspa_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="30"/>
        <source>LADSPA Plugin</source>
        <translation>LADSPA プラグイン</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="50"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>QMMP 用の LADSPA ホストについて</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>QMMP 用の LADSPA ホスト</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>BMP 用 LADSPA ホストに基づく</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>BMP-ladspa developers:</source>
        <translation>BMP-ladspa 開発者:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>LADSPA プラグインカタログ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>調整</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>この LADSPA プラグインにユーザが制御できる部分はありません</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.2-1.00.tar.gz: qmmp-1.0.0/src/plugins/Effect/ladspa/translations/ladspa_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>LADSPA プラグイン</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>QMMP 用の LADSPA ホストについて</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>QMMP 用の LADSPA ホスト</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>BMP 用 LADSPA ホストを基に作成</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>BMP-ladspa 開発者:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>LADSPA プラグインカタログ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>調整</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>この LADSPA プラグインにユーザーが制御できる部分はありません</translation>
    </message>
</context>
</TS>
